@@ -166,6 +166,8 @@ class GraphomalyEstimator(BaseEstimator):
         self.models_name = []
         self.feature_names_in_ = []
 
+        self._model_is_fitted = False
+
         # tune
         self.best_estimators = {}
         self.best_labels_ = {}
@@ -369,10 +371,36 @@ class GraphomalyEstimator(BaseEstimator):
             example of performing fit on synthetic
             generated data on a small subset of methods and parameters list.
         """
+        if self._model_is_fitted is True:
+            return self
+
         self.tune(X, y)
+        self._model_is_fitted = True
 
         return self
 
+    def refit(self, X, y=None):
+        """Retrain anomaly detection models on samples in `X`.
+
+        Parameters
+        ----------
+        X: array-like of shape (n_samples, n_features)
+            samples on which to fit the methods in `models_list`
+
+        y: array-like of shape (n_samples, )
+            The ground truth for samples `X`. If `None` then the best estimator
+            across parameter opotions will not be sought.
+
+        Returns
+        -------
+        self: object
+            Re-Fitted estimator.
+        """
+        if self._model_is_fitted is False:
+            return
+
+        self.tune(X, y, refit=True)
+
     def predict(self, X, y=None, voting=None):
         """Perform anomaly detection on samples in `X`.
 
@@ -436,7 +464,7 @@ class GraphomalyEstimator(BaseEstimator):
         y = eclf.fit_predict(X, y)
         return y
 
-    def tune(self, X, y=None):
+    def tune(self, X, y=None, refit=False):
         """Perform parameter tuning on samples in `X` using Graphomaly's
         `GridSearch`.
 
@@ -449,6 +477,10 @@ class GraphomalyEstimator(BaseEstimator):
             The ground truth for samples `X`. If `None` then the best estimator
             information will not be set.
 
+        refit: bool, default=False
+            If this is a refit, clean existing model before proceeding with
+            GridSearch.
+
         Returns
         -------
         self: object
@@ -474,6 +506,7 @@ class GraphomalyEstimator(BaseEstimator):
                 n_cpus=self.n_cpus,
                 datadir=self.results_path,
                 clf_type=clf_type,
+                refit=refit,
             )
             search.fit(X, y)
 
