@@ -200,6 +200,7 @@ class GridSearch:
         clf_type="sklearn",
         get_results=None,
         compare_metric=None,
+        refit=False,
     ):
         self.base_clf = clf
         self.datadir = datadir
@@ -207,6 +208,7 @@ class GridSearch:
         self.clf_type = clf_type
 
         self.params = params
+        self.refit = refit
 
         self.clf_name = clf.__class__.__name__
 
@@ -299,10 +301,18 @@ class GridSearch:
 
         self.params = list(ParameterGrid(self.params))
 
+    def _experiment_get_path(self, prefix, p):
+        return prefix + self._experiment_file_params(p)
+
     def _experiment_exists(self, prefix, p):
-        experiment = prefix + self._experiment_file_params(p)
+        experiment = self._experiment_get_path(prefix, p)
         return os.path.isfile(experiment)
 
+    def _experiment_remove_if_exists(self, prefix, p):
+        experiment = self._experiment_get_path(prefix, p)
+        if os.path.isfile(experiment):
+            os.remove(experiment)
+
     def _experiment_file_params(self, p):
         str_params = ""
         for k, v in p.items():
@@ -326,6 +336,12 @@ class GridSearch:
         to_str = to_hex[:n_digits]
         return to_str
 
+    def _grid_remove_existing_experiments(self):
+        prefix = f"{self.datadir}/{self.clf_name}"
+        self.params_in_ = self.params
+        for p in self.params:
+            self._experiment_remove_if_exists(prefix, p)
+
     def _grid_remove_existing_tests(self):
         prefix = f"{self.datadir}/{self.clf_name}"
         self.params_in_ = self.params
@@ -367,7 +383,9 @@ class GridSearch:
         experiments = list(p.glob(f"{self.clf_name}-*"))
         for experiment in experiments:
             with open(experiment, "rb") as fp:
-                [clf, ba, tpr, tnr, duration, tn, fp, fn, tp] = pickle.load(fp)
+                # [clf, ba, tpr, tnr, duration, tn, fp, fn, tp] = pickle.load(fp)
+                metrics = pickle.load(fp)
+                clf = metrics["clf"]
                 self.estimators_.append(clf)
                 print(experiment)
                 print(clf)
@@ -392,7 +410,10 @@ class GridSearch:
 
     def _grid_search(self, X, y):
         self._grid_generate_search_space(X, y)
-        self._grid_remove_existing_tests()
+        if self.refit:
+            self._grid_remove_existing_experiments()
+        else:
+            self._grid_remove_existing_tests()
 
         # tf incompatible with mp according to tf issue #46316
         if self.n_cpus == 1 or self.clf_type == "tensorflow":
